@@ -13,7 +13,7 @@ main (int argc, char *argv[])
     else if (argv[i] == std::string ("-s"))
       driver.trace_scanning = true;
     else if (!driver.parse (argv[i]))
-      std::cout << driver.result << std::endl;
+      std::cout << driver.result << '\n';
     else
       res = 1;
   return res;
